package com.example.shoesapptest.ui

import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.activity.enableEdgeToEdge
import androidx.navigation.compose.NavHost
import androidx.navigation.compose.composable
import androidx.navigation.compose.rememberNavController
import com.example.shoesapp.ui.screen.SigninScreen
import com.example.shoesapp.ui.theme.MatuleTheme
import com.example.shoesapptest.Screen
import com.example.shoesapptest.data.local.DataStore
import com.example.shoesapptest.data.remote.RetrofitClient

import com.example.shoesapptest.data.AuthRepository
import com.example.shoesapptest.domain.usecase.AuthUseCase
import com.example.shoesapptest.screen.ForgotPasswordScreen
import com.example.shoesapptest.screen.regscreen.RegistrationScreen

import com.example.shoesapptest.ui.screen.registrationscreen.Registration
import com.example.shoesapptest.ui.screen.registrationscreen.RegistrationViewModel
import org.koin.androidx.viewmodel.ext.android.viewModel

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        enableEdgeToEdge()

        val registrationViewModel: RegistrationViewModel by viewModel()
        setContent {
            val navController = rememberNavController()
            MatuleTheme {
                NavHost(
                    navController = navController,
                    startDestination = "signin"
                ) {
                    composable(Screen.SignIn.route) {
                        SigninScreen(
                            onNavigationToRegScreen = {
                                navController.navigate("registration")
                            },
                            navController = navController
                        )
                    }
                    composable(Screen.ForgotPass.route) {
                        ForgotPasswordScreen(onNavigateToSignInScreen = {
                            navController.navigate("signin")
                        })
                    }
                    composable(Screen.Registration.route) {
                        RegistrationScreen(
                            onNavigationToSigninScreen = {
                                navController.popBackStack()
                            }
                        )
                    }
                }
            }
        }
    }
}