package com.example.shoesapptest.domain.usecase

import com.example.shoesapptest.data.AuthRepository
import com.example.shoesapptest.data.local.DataStore
import com.example.shoesapptest.data.remote.NetworkResponse
import com.example.shoesapptest.data.remote.dto.request.RegistrationRequest
import kotlinx.coroutines.flow.Flow
import kotlinx.coroutines.flow.flow

class AuthUseCase (private val  localStorage: DataStore,
    private val authRepository: AuthRepository) {
    val token: Flow<String> = localStorage.tokenFlow
    suspend fun registration(registrationRequest: RegistrationRequest): Flow<NetworkResponse> = flow{
        try{
            emit(NetworkResponse.Loading)
            val result = authRepository.registration(registrationRequest)
            localStorage.setToken(result.second)
            emit(NetworkResponse.Success(result))
        }
        catch (e:Exception){
            e.message?.let{
                emit(NetworkResponse.Error(it))
                return@flow
            }
            emit(NetworkResponse.Error("Unknown Error"))
        }
    }
}