package com.example.shoesapptest.ui.screen.registrationscreen

import androidx.compose.runtime.derivedStateOf
import androidx.compose.runtime.mutableStateOf
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.example.shoesapptest.data.remote.dto.request.RegistrationRequest
import com.example.shoesapptest.data.AuthRepository
import com.example.shoesapptest.screen.regscreen.RegistrationScreen
import kotlinx.coroutines.launch

class RegistrationViewModel(
    private val authRepository: AuthRepository
):ViewModel() {

    var registration = mutableStateOf(Registration())
        private set
    val emailHasError = derivedStateOf {
        if (registration.value.email.isEmpty()) return@derivedStateOf false
        !android.util.Patterns.EMAIL_ADDRESS.matcher(registration.value.email).matches()
    }
    fun setEmail(email: String){
        registration.value=registration.value.copy(email=email)
    }
    fun setPassword(password: String){
        registration.value = registration.value.copy(password=password)
    }
    fun setUserName(name: String){
        registration.value = registration.value.copy(name=name)
    }
    fun setErrorMessage(message: String?){
        registration.value=registration.value.copy(errorMessage = message)
    }
    fun registration(onSuccess: () -> Unit){
        viewModelScope.launch {
            try {
                val registrationRequest = RegistrationRequest(
                    userName = registration.value.name,
                    email = registration.value.email,
                    password = registration.value.password
                )
                onSuccess()
            } catch (e: Exception) {
                registration.value = registration.value.copy(errorMessage = "Ошибка регистрации: ${e.message}")
            }
        }
    }
}